@@ -92,9 +92,8 @@ class ReSiStanceFeedDict(feedparser.FeedParserDict):
             if not 'read' in entry:
                 entry['read'] = False
 
-        if sync != None:
-            if not 'sync' in self:
-                self['sync'] = sync
+        if not 'sync' in self:
+            self['sync'] = sync if sync != None else False
 
 class FeedManager(gobject.GObject):
 
