@@ -731,7 +731,7 @@ class FeedsWindow(hildon.StackableWindow):
                   self.FEEDS_MODEL_READ_COLUMN, self._get_visual_unread_text(len(new_feed_data.entries)),
                   self.FEEDS_MODEL_VISITS_COLUMN, new_feed_data.visits,
                   self.FEEDS_MODEL_SYNC_COLUMN, new_feed_data.sync,
-                  self.FEEDS_MODEL_ID_COLUMN, id(new_feed_data))
+                  self.FEEDS_MODEL_ID_COLUMN, hash(new_feed_data.href))
 
         # Take screenshot
         hildon.hildon_gtk_window_take_screenshot(self, False)
@@ -920,7 +920,7 @@ class FeedsWindow(hildon.StackableWindow):
                           self.FEEDS_MODEL_READ_COLUMN, self._get_visual_unread_text(unread_count),
                           self.FEEDS_MODEL_VISITS_COLUMN, feed_data.visits,
                           self.FEEDS_MODEL_SYNC_COLUMN, feed_data.sync,
-                          self.FEEDS_MODEL_ID_COLUMN, id(feed_data))
+                          self.FEEDS_MODEL_ID_COLUMN, hash(feed_data.href))
                 # Favicon might require a network download
                 path = self.view.get_model().get_path(feed_iter)
                 row_reference = gtk.TreeRowReference(store, path)
