@@ -42,6 +42,9 @@ class Settings(object):
         self.rotation_mode = FremantleRotation.AUTOMATIC
         self.auto_download = False
         self.auto_download_folder = '/home/user/MyDocs'
+        self.user  = ''
+        self.password = ''
+        self.sync_global = False
 
     def load(self):
         if not (os.path.exists(constants.RSS_CONF_FILE) and
@@ -55,11 +58,14 @@ class Settings(object):
                 return
 
         self.feeds_order = self.config['feeds_order']
-        self.default_font_size = self.config['default_font_size']
+        self.default_font_size = int(self.config['default_font_size'])
         self.auto_load_images = self.config['auto_load_images']
         self.rotation_mode = self.config['rotation_mode']
         self.auto_download = self.config['auto_download'] if 'auto_download' in self.config else False
         self.auto_download_folder = self.config['auto_download_folder'] if 'auto_download_folder' in self.config else '/home/user/MyDocs'
+        self.user = self.config['user'] if 'user' in self.config else ''
+        self.password = self.config['password'] if 'password' in self.config else ''
+        self.sync_global = self.config['sync_global'] if 'sync_global' in self.config else False
 
     def save(self):
         if self.config == None:
@@ -72,5 +78,8 @@ class Settings(object):
         self.config['rotation_mode'] = self.rotation_mode
         self.config['auto_download'] = self.auto_download
         self.config['auto_download_folder'] = self.auto_download_folder
+        self.config['user'] = self.user
+        self.config['password'] = self.password
+        self.config['sync_global'] = self.sync_global
 
         self.config.write()
